@@ -1,11 +1,17 @@
+//! # bevy_serial
+//!
 //! `bevy_serial` is a plugin to add non-blocking serial communication to bevy. This plugin is based on [`mio-serial`](https://github.com/berkowski/mio-serial)
-//! that can realize non-blocking high performance I/O.
+//! that can realize non-blocking high-performance I/O.
 //!
 //! Reading and writing from/to serial port is realized via bevy's event system. Each serial port is handled via port
-//! name or a unique label you choose.
+//! name or a unique label you choose. These event handlers are added to the following stage to minimize the frame delay.
 //!
+//! - Reading: `CoreStage::PreUpdate`
+//! - Writing: `CoreStage::PostUpdate`
 //!
-//! ## Simple Example
+//! ## Usage
+//!
+//! ### Simple Example
 //!
 //! Here is a simple example:
 //!
@@ -52,7 +58,7 @@
 //! }
 //! ```
 //!
-//! ## Multiple Serial Ports with Additional Settings
+//! ### Multiple Serial Ports with Additional Settings
 //!
 //! You can add multiple serial ports with additional settings.
 //!
@@ -120,14 +126,18 @@
 //! | ---- | ----------- |
 //! | 0.6  | 0.2         |
 //! | 0.5  | 0.1         |
-//
+//!
 //! ## License
-//
-//! MIT
+//!
+//! Dual-licensed under either
+//!
+//! - MIT
+//! - Apache 2.0
+
 
 pub use mio_serial::{DataBits, FlowControl, Parity, StopBits};
 
-use bevy::app::{App, EventReader, EventWriter, Plugin};
+use bevy::app::{App, CoreStage, EventReader, EventWriter, Plugin};
 use bevy::ecs::system::{Res, ResMut};
 use mio::{Events, Interest, Poll, Token};
 use mio_serial::SerialStream;
@@ -269,8 +279,8 @@ impl Plugin for SerialPlugin {
             .insert_resource(indices)
             .add_event::<SerialReadEvent>()
             .add_event::<SerialWriteEvent>()
-            .add_system(read_serial)
-            .add_system(write_serial);
+            .add_system_to_stage(CoreStage::PreUpdate, read_serial)
+            .add_system_to_stage(CoreStage::PostUpdate, write_serial);
     }
 }
 
